#ifndef INCLUDED_QERESOURCES_H
#define INCLUDED_QERESOURCES_H

#include <resource-file.h>

/**
 * Class for representing ecawave user settings (~/.ecawaverc)
 */
class QEResources : public RESOURCE_FILE {

 public:

  void set_defaults(void);

  QEResources(void);
};

#endif
